searchData={"content_type":"text/markdown","items":[{"doc":"The main entry point into Testcontainers.\n\nThis is a GenServer that needs to be started before anything can happen.","ref":"Testcontainers.html","title":"Testcontainers","type":"module"},{"doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"Testcontainers.html#child_spec/1","title":"Testcontainers.child_spec/1","type":"function"},{"doc":"Starts a new container based on the provided configuration, applying any specified wait strategies.\n\nThis function performs several steps:\n1. Pulls the necessary Docker image.\n2. Creates and starts a container with the specified configuration.\n3. Registers the container with a reaper process for automatic cleanup, ensuring it is stopped and removed when the current process exits or in case of unforeseen failures.","ref":"Testcontainers.html#start_container/2","title":"Testcontainers.start_container/2","type":"function"},{"doc":"- `config`: A `%Container{}` struct containing the configuration settings for the container, such as the image to use, environment variables, bound ports, and volume bindings.","ref":"Testcontainers.html#start_container/2-parameters","title":"Parameters - Testcontainers.start_container/2","type":"function"},{"doc":"iex> config = Testcontainers.MySqlContainer.new()\n    iex> {:ok, container} = Testcontainers.start_container(config)","ref":"Testcontainers.html#start_container/2-examples","title":"Examples - Testcontainers.start_container/2","type":"function"},{"doc":"- `{:ok, container}` if the container is successfully created, started, and passes all wait strategies.\n- An error tuple, such as `{:error, reason}`, if there is a failure at any step in the process.","ref":"Testcontainers.html#start_container/2-returns","title":"Returns - Testcontainers.start_container/2","type":"function"},{"doc":"- The container is automatically registered with a reaper process, ensuring it is stopped and removed when the current process exits, or in the case of unforeseen failures.\n- It's important to specify appropriate wait strategies to ensure the container is fully ready for interaction, especially for containers that may take some time to start up services internally.","ref":"Testcontainers.html#start_container/2-notes","title":"Notes - Testcontainers.start_container/2","type":"function"},{"doc":"","ref":"Testcontainers.html#start_link/1","title":"Testcontainers.start_link/1","type":"function"},{"doc":"Stops a running container.\n\nThis sends a stop command to the specified container. The Docker daemon terminates the container process gracefully.","ref":"Testcontainers.html#stop_container/2","title":"Testcontainers.stop_container/2","type":"function"},{"doc":"- `container_id`: The ID of the container to stop, as a string.","ref":"Testcontainers.html#stop_container/2-parameters","title":"Parameters - Testcontainers.stop_container/2","type":"function"},{"doc":"- `:ok` if the container stops successfully.\n- `{:error, reason}` on failure.","ref":"Testcontainers.html#stop_container/2-returns","title":"Returns - Testcontainers.stop_container/2","type":"function"},{"doc":":ok = Testcontainers.Connection.stop_container(\"my_container_id\")","ref":"Testcontainers.html#stop_container/2-examples","title":"Examples - Testcontainers.stop_container/2","type":"function"},{"doc":"Provides functionality for creating and managing Cassandra container configurations.","ref":"Testcontainers.CassandraContainer.html","title":"Testcontainers.CassandraContainer","type":"module"},{"doc":"Generates the connection URL for accessing the Cassandra service running within the container.","ref":"Testcontainers.CassandraContainer.html#connection_uri/1","title":"Testcontainers.CassandraContainer.connection_uri/1","type":"function"},{"doc":"","ref":"Testcontainers.CassandraContainer.html#default_image/0","title":"Testcontainers.CassandraContainer.default_image/0","type":"function"},{"doc":"","ref":"Testcontainers.CassandraContainer.html#default_port/0","title":"Testcontainers.CassandraContainer.default_port/0","type":"function"},{"doc":"","ref":"Testcontainers.CassandraContainer.html#get_password/0","title":"Testcontainers.CassandraContainer.get_password/0","type":"function"},{"doc":"","ref":"Testcontainers.CassandraContainer.html#get_username/0","title":"Testcontainers.CassandraContainer.get_username/0","type":"function"},{"doc":"","ref":"Testcontainers.CassandraContainer.html#new/0","title":"Testcontainers.CassandraContainer.new/0","type":"function"},{"doc":"Retrieves the port mapped by the Docker host for the Cassandra container.","ref":"Testcontainers.CassandraContainer.html#port/1","title":"Testcontainers.CassandraContainer.port/1","type":"function"},{"doc":"Set the regular expression to check the image validity.","ref":"Testcontainers.CassandraContainer.html#with_check_image/2","title":"Testcontainers.CassandraContainer.with_check_image/2","type":"function"},{"doc":"","ref":"Testcontainers.CassandraContainer.html#with_image/2","title":"Testcontainers.CassandraContainer.with_image/2","type":"function"},{"doc":"Provides functionality for creating and managing Ceph container configurations.","ref":"Testcontainers.CephContainer.html","title":"Testcontainers.CephContainer","type":"module"},{"doc":"Generates the connection options for accessing the Ceph service running within the container.\nCompatible with what ex_aws expects in `ExAws.request(options)`","ref":"Testcontainers.CephContainer.html#connection_opts/1","title":"Testcontainers.CephContainer.connection_opts/1","type":"function"},{"doc":"Generates the connection URL for accessing the Ceph service running within the container.\n\nThis URL is based on the standard localhost IP and the mapped port for the container.","ref":"Testcontainers.CephContainer.html#connection_url/1","title":"Testcontainers.CephContainer.connection_url/1","type":"function"},{"doc":"- `container`: The active Ceph container instance.","ref":"Testcontainers.CephContainer.html#connection_url/1-parameters","title":"Parameters - Testcontainers.CephContainer.connection_url/1","type":"function"},{"doc":"iex> CephContainer.connection_url(container)\n    \"http://localhost:32768\" # This value will be different depending on the mapped port.","ref":"Testcontainers.CephContainer.html#connection_url/1-examples","title":"Examples - Testcontainers.CephContainer.connection_url/1","type":"function"},{"doc":"Retrieves the default Docker image used for the Ceph container.","ref":"Testcontainers.CephContainer.html#default_image/0","title":"Testcontainers.CephContainer.default_image/0","type":"function"},{"doc":"iex> CephContainer.default_image()\n    \"quay.io/ceph/demo\"","ref":"Testcontainers.CephContainer.html#default_image/0-examples","title":"Examples - Testcontainers.CephContainer.default_image/0","type":"function"},{"doc":"Creates a new `CephContainer` struct with default attributes.","ref":"Testcontainers.CephContainer.html#new/0","title":"Testcontainers.CephContainer.new/0","type":"function"},{"doc":"Retrieves the port mapped by the Docker host for the Ceph container.","ref":"Testcontainers.CephContainer.html#port/1","title":"Testcontainers.CephContainer.port/1","type":"function"},{"doc":"- `container`: The active Ceph container instance.","ref":"Testcontainers.CephContainer.html#port/1-parameters","title":"Parameters - Testcontainers.CephContainer.port/1","type":"function"},{"doc":"iex> CephContainer.port(container)\n    32768 # This value will be different depending on the mapped port.","ref":"Testcontainers.CephContainer.html#port/1-examples","title":"Examples - Testcontainers.CephContainer.port/1","type":"function"},{"doc":"Sets the `access_key` used for authentication with the Ceph container.","ref":"Testcontainers.CephContainer.html#with_access_key/2","title":"Testcontainers.CephContainer.with_access_key/2","type":"function"},{"doc":"iex> config = CephContainer.new()\n    iex> new_config = CephContainer.with_access_key(config, \"new_access_key\")\n    iex> new_config.access_key\n    \"new_access_key\"","ref":"Testcontainers.CephContainer.html#with_access_key/2-examples","title":"Examples - Testcontainers.CephContainer.with_access_key/2","type":"function"},{"doc":"Sets the `bucket` that is automatically in the Ceph container.","ref":"Testcontainers.CephContainer.html#with_bucket/2","title":"Testcontainers.CephContainer.with_bucket/2","type":"function"},{"doc":"iex> config = CephContainer.new()\n    iex> new_config = CephContainer.with_bucket(config, \"test_bucket\")\n    iex> new_config.bucket\n    \"test_bucket\"","ref":"Testcontainers.CephContainer.html#with_bucket/2-examples","title":"Examples - Testcontainers.CephContainer.with_bucket/2","type":"function"},{"doc":"Set the regular expression to check the image validity.","ref":"Testcontainers.CephContainer.html#with_check_image/2","title":"Testcontainers.CephContainer.with_check_image/2","type":"function"},{"doc":"Sets the `image` of the Ceph container configuration.","ref":"Testcontainers.CephContainer.html#with_image/2","title":"Testcontainers.CephContainer.with_image/2","type":"function"},{"doc":"iex> config = CephContainer.new()\n    iex> new_config = CephContainer.with_image(config, \"quay.io/ceph/alternative\")\n    iex> new_config.image\n    \"quay.io/ceph/alternative\"","ref":"Testcontainers.CephContainer.html#with_image/2-examples","title":"Examples - Testcontainers.CephContainer.with_image/2","type":"function"},{"doc":"Sets the port on which the Ceph container will be exposed.","ref":"Testcontainers.CephContainer.html#with_port/2","title":"Testcontainers.CephContainer.with_port/2","type":"function"},{"doc":"- `config`: The current Ceph container configuration.\n- `port`: The target port number.","ref":"Testcontainers.CephContainer.html#with_port/2-parameters","title":"Parameters - Testcontainers.CephContainer.with_port/2","type":"function"},{"doc":"iex> config = CephContainer.new()\n    iex> new_config = CephContainer.with_port(config, 8081)\n    iex> new_config.port\n    8081","ref":"Testcontainers.CephContainer.html#with_port/2-examples","title":"Examples - Testcontainers.CephContainer.with_port/2","type":"function"},{"doc":"Sets the `secret_key` used for authentication with the Ceph container.","ref":"Testcontainers.CephContainer.html#with_secret_key/2","title":"Testcontainers.CephContainer.with_secret_key/2","type":"function"},{"doc":"iex> config = CephContainer.new()\n    iex> new_config = CephContainer.with_secret_key(config, \"new_secret_key\")\n    iex> new_config.secret_key\n    \"new_secret_key\"","ref":"Testcontainers.CephContainer.html#with_secret_key/2-examples","title":"Examples - Testcontainers.CephContainer.with_secret_key/2","type":"function"},{"doc":"Sets the maximum time (in milliseconds) the system will wait for the Ceph container to be ready before timing out.","ref":"Testcontainers.CephContainer.html#with_wait_timeout/2","title":"Testcontainers.CephContainer.with_wait_timeout/2","type":"function"},{"doc":"- `config`: The current Ceph container configuration.\n- `wait_timeout`: The time to wait in milliseconds.","ref":"Testcontainers.CephContainer.html#with_wait_timeout/2-parameters","title":"Parameters - Testcontainers.CephContainer.with_wait_timeout/2","type":"function"},{"doc":"iex> config = CephContainer.new()\n    iex> new_config = CephContainer.with_wait_timeout(config, 400_000)\n    iex> new_config.wait_timeout\n    400_000","ref":"Testcontainers.CephContainer.html#with_wait_timeout/2-examples","title":"Examples - Testcontainers.CephContainer.with_wait_timeout/2","type":"function"},{"doc":"Considers a container ready as soon as a command runs successfully inside it.","ref":"Testcontainers.CommandWaitStrategy.html","title":"Testcontainers.CommandWaitStrategy","type":"module"},{"doc":"Creates a new CommandWaitStrategy.\nThis strategy waits until the given command executes successfully inside the container.","ref":"Testcontainers.CommandWaitStrategy.html#new/3","title":"Testcontainers.CommandWaitStrategy.new/3","type":"function"},{"doc":"A struct with builder functions for creating a definition of a container.","ref":"Testcontainers.Container.html","title":"Testcontainers.Container","type":"module"},{"doc":"","ref":"Testcontainers.Container.html#is_os/1","title":"Testcontainers.Container.is_os/1","type":"macro"},{"doc":"Returns `true` if `term` is a valid `check_image`, otherwise returns `false`.","ref":"Testcontainers.Container.html#is_valid_image/1","title":"Testcontainers.Container.is_valid_image/1","type":"macro"},{"doc":"Gets the host port on the container for the given exposed port.","ref":"Testcontainers.Container.html#mapped_port/2","title":"Testcontainers.Container.mapped_port/2","type":"function"},{"doc":"A constructor function to make it easier to construct a container","ref":"Testcontainers.Container.html#new/1","title":"Testcontainers.Container.new/1","type":"function"},{"doc":"Check if the provided image is compatible with the expected default image.","ref":"Testcontainers.Container.html#valid_image/1","title":"Testcontainers.Container.valid_image/1","type":"function"},{"doc":"Check if the provided image is compatible with the expected default image.\n\nRaises:\n\nArgumentError when image isn't compatible.","ref":"Testcontainers.Container.html#valid_image!/1","title":"Testcontainers.Container.valid_image!/1","type":"function"},{"doc":"Adds authentication token for registries that require a login.","ref":"Testcontainers.Container.html#with_auth/3","title":"Testcontainers.Container.with_auth/3","type":"function"},{"doc":"Sets whether the container should be automatically removed on exit.","ref":"Testcontainers.Container.html#with_auto_remove/2","title":"Testcontainers.Container.with_auto_remove/2","type":"function"},{"doc":"Sets a file or the directory on the _host machine_ to be mounted into a _container_.","ref":"Testcontainers.Container.html#with_bind_mount/4","title":"Testcontainers.Container.with_bind_mount/4","type":"function"},{"doc":"Sets a volume to be mounted into a container on target path","ref":"Testcontainers.Container.html#with_bind_volume/4","title":"Testcontainers.Container.with_bind_volume/4","type":"function"},{"doc":"Set the regular expression to check the image validity.\n\nWhen using a string, it will compile it to a regular expression. If the compilation fails, it will raise a `Regex.CompileError`.","ref":"Testcontainers.Container.html#with_check_image/2","title":"Testcontainers.Container.with_check_image/2","type":"function"},{"doc":"Sets a cmd to run when the container starts.","ref":"Testcontainers.Container.html#with_cmd/2","title":"Testcontainers.Container.with_cmd/2","type":"function"},{"doc":"Sets an _environment variable_ to the _container_.","ref":"Testcontainers.Container.html#with_environment/3","title":"Testcontainers.Container.with_environment/3","type":"function"},{"doc":"Adds a _port_ to be exposed on the _container_.","ref":"Testcontainers.Container.html#with_exposed_port/2","title":"Testcontainers.Container.with_exposed_port/2","type":"function"},{"doc":"Adds multiple _ports_ to be exposed on the _container_.","ref":"Testcontainers.Container.html#with_exposed_ports/2","title":"Testcontainers.Container.with_exposed_ports/2","type":"function"},{"doc":"Adds a fixed _port_ to be exposed on the _container_.\nThis approach to managing ports is not recommended by Testcontainers.\nUse at your own risk.","ref":"Testcontainers.Container.html#with_fixed_port/3","title":"Testcontainers.Container.with_fixed_port/3","type":"function"},{"doc":"Sets a label to apply to the container object in docker.","ref":"Testcontainers.Container.html#with_label/3","title":"Testcontainers.Container.with_label/3","type":"function"},{"doc":"Sets a network mode to apply to the container object in docker.","ref":"Testcontainers.Container.html#with_network_mode/2","title":"Testcontainers.Container.with_network_mode/2","type":"function"},{"doc":"Sets multiple _waiting strategies_ for the _container_.","ref":"Testcontainers.Container.html#with_waiting_strategies/2","title":"Testcontainers.Container.with_waiting_strategies/2","type":"function"},{"doc":"Sets a _waiting strategy_ for the _container_.","ref":"Testcontainers.Container.html#with_waiting_strategy/2","title":"Testcontainers.Container.with_waiting_strategy/2","type":"function"},{"doc":"Deprecated. Use `Testcontainers.CephContainer` instead.\n\nThis module is kept for backward compatibility and will be removed in future releases.","ref":"Testcontainers.Container.CephContainer.html","title":"Testcontainers.Container.CephContainer","type":"module"},{"doc":"","ref":"Testcontainers.Container.CephContainer.html#connection_url/1","title":"Testcontainers.Container.CephContainer.connection_url/1","type":"function"},{"doc":"","ref":"Testcontainers.Container.CephContainer.html#new/0","title":"Testcontainers.Container.CephContainer.new/0","type":"function"},{"doc":"","ref":"Testcontainers.Container.CephContainer.html#port/1","title":"Testcontainers.Container.CephContainer.port/1","type":"function"},{"doc":"","ref":"Testcontainers.Container.CephContainer.html#with_access_key/2","title":"Testcontainers.Container.CephContainer.with_access_key/2","type":"function"},{"doc":"","ref":"Testcontainers.Container.CephContainer.html#with_bucket/2","title":"Testcontainers.Container.CephContainer.with_bucket/2","type":"function"},{"doc":"","ref":"Testcontainers.Container.CephContainer.html#with_image/2","title":"Testcontainers.Container.CephContainer.with_image/2","type":"function"},{"doc":"","ref":"Testcontainers.Container.CephContainer.html#with_port/2","title":"Testcontainers.Container.CephContainer.with_port/2","type":"function"},{"doc":"","ref":"Testcontainers.Container.CephContainer.html#with_secret_key/2","title":"Testcontainers.Container.CephContainer.with_secret_key/2","type":"function"},{"doc":"","ref":"Testcontainers.Container.CephContainer.html#with_wait_timeout/2","title":"Testcontainers.Container.CephContainer.with_wait_timeout/2","type":"function"},{"doc":"Deprecated. Use `Testcontainers.MySqlContainer` instead.\n\nThis module is kept for backward compatibility and will be removed in future releases.","ref":"Testcontainers.Container.MySqlContainer.html","title":"Testcontainers.Container.MySqlContainer","type":"module"},{"doc":"","ref":"Testcontainers.Container.MySqlContainer.html#connection_parameters/1","title":"Testcontainers.Container.MySqlContainer.connection_parameters/1","type":"function"},{"doc":"","ref":"Testcontainers.Container.MySqlContainer.html#default_image_with_tag/0","title":"Testcontainers.Container.MySqlContainer.default_image_with_tag/0","type":"function"},{"doc":"","ref":"Testcontainers.Container.MySqlContainer.html#default_port/0","title":"Testcontainers.Container.MySqlContainer.default_port/0","type":"function"},{"doc":"","ref":"Testcontainers.Container.MySqlContainer.html#new/0","title":"Testcontainers.Container.MySqlContainer.new/0","type":"function"},{"doc":"","ref":"Testcontainers.Container.MySqlContainer.html#port/1","title":"Testcontainers.Container.MySqlContainer.port/1","type":"function"},{"doc":"","ref":"Testcontainers.Container.MySqlContainer.html#with_database/2","title":"Testcontainers.Container.MySqlContainer.with_database/2","type":"function"},{"doc":"","ref":"Testcontainers.Container.MySqlContainer.html#with_image/2","title":"Testcontainers.Container.MySqlContainer.with_image/2","type":"function"},{"doc":"","ref":"Testcontainers.Container.MySqlContainer.html#with_password/2","title":"Testcontainers.Container.MySqlContainer.with_password/2","type":"function"},{"doc":"","ref":"Testcontainers.Container.MySqlContainer.html#with_port/2","title":"Testcontainers.Container.MySqlContainer.with_port/2","type":"function"},{"doc":"","ref":"Testcontainers.Container.MySqlContainer.html#with_user/2","title":"Testcontainers.Container.MySqlContainer.with_user/2","type":"function"},{"doc":"","ref":"Testcontainers.Container.MySqlContainer.html#with_wait_timeout/2","title":"Testcontainers.Container.MySqlContainer.with_wait_timeout/2","type":"function"},{"doc":"Deprecated. Use `Testcontainers.PostgresContainer` instead.\n\nThis module is kept for backward compatibility and will be removed in future releases.","ref":"Testcontainers.Container.PostgresContainer.html","title":"Testcontainers.Container.PostgresContainer","type":"module"},{"doc":"","ref":"Testcontainers.Container.PostgresContainer.html#connection_parameters/1","title":"Testcontainers.Container.PostgresContainer.connection_parameters/1","type":"function"},{"doc":"","ref":"Testcontainers.Container.PostgresContainer.html#default_image_with_tag/0","title":"Testcontainers.Container.PostgresContainer.default_image_with_tag/0","type":"function"},{"doc":"","ref":"Testcontainers.Container.PostgresContainer.html#default_port/0","title":"Testcontainers.Container.PostgresContainer.default_port/0","type":"function"},{"doc":"","ref":"Testcontainers.Container.PostgresContainer.html#new/0","title":"Testcontainers.Container.PostgresContainer.new/0","type":"function"},{"doc":"","ref":"Testcontainers.Container.PostgresContainer.html#port/1","title":"Testcontainers.Container.PostgresContainer.port/1","type":"function"},{"doc":"","ref":"Testcontainers.Container.PostgresContainer.html#with_database/2","title":"Testcontainers.Container.PostgresContainer.with_database/2","type":"function"},{"doc":"","ref":"Testcontainers.Container.PostgresContainer.html#with_image/2","title":"Testcontainers.Container.PostgresContainer.with_image/2","type":"function"},{"doc":"","ref":"Testcontainers.Container.PostgresContainer.html#with_password/2","title":"Testcontainers.Container.PostgresContainer.with_password/2","type":"function"},{"doc":"","ref":"Testcontainers.Container.PostgresContainer.html#with_port/2","title":"Testcontainers.Container.PostgresContainer.with_port/2","type":"function"},{"doc":"","ref":"Testcontainers.Container.PostgresContainer.html#with_user/2","title":"Testcontainers.Container.PostgresContainer.with_user/2","type":"function"},{"doc":"","ref":"Testcontainers.Container.PostgresContainer.html#with_wait_timeout/2","title":"Testcontainers.Container.PostgresContainer.with_wait_timeout/2","type":"function"},{"doc":"Deprecated. Use `Testcontainers.RedisContainer` instead.\n\nThis module is kept for backward compatibility and will be removed in future releases.","ref":"Testcontainers.Container.RedisContainer.html","title":"Testcontainers.Container.RedisContainer","type":"module"},{"doc":"","ref":"Testcontainers.Container.RedisContainer.html#connection_url/1","title":"Testcontainers.Container.RedisContainer.connection_url/1","type":"function"},{"doc":"","ref":"Testcontainers.Container.RedisContainer.html#new/0","title":"Testcontainers.Container.RedisContainer.new/0","type":"function"},{"doc":"","ref":"Testcontainers.Container.RedisContainer.html#port/1","title":"Testcontainers.Container.RedisContainer.port/1","type":"function"},{"doc":"","ref":"Testcontainers.Container.RedisContainer.html#with_image/2","title":"Testcontainers.Container.RedisContainer.with_image/2","type":"function"},{"doc":"","ref":"Testcontainers.Container.RedisContainer.html#with_port/2","title":"Testcontainers.Container.RedisContainer.with_port/2","type":"function"},{"doc":"","ref":"Testcontainers.Container.RedisContainer.html#with_wait_timeout/2","title":"Testcontainers.Container.RedisContainer.with_wait_timeout/2","type":"function"},{"doc":"Deprecated. Use `Testcontainers.SeleniumContainer` instead.\n\nThis module is kept for backward compatibility and will be removed in future releases.","ref":"Testcontainers.Container.SeleniumContainer.html","title":"Testcontainers.Container.SeleniumContainer","type":"module"},{"doc":"","ref":"Testcontainers.Container.SeleniumContainer.html#new/0","title":"Testcontainers.Container.SeleniumContainer.new/0","type":"function"},{"doc":"","ref":"Testcontainers.Container.SeleniumContainer.html#with_image/2","title":"Testcontainers.Container.SeleniumContainer.with_image/2","type":"function"},{"doc":"","ref":"Testcontainers.Container.SeleniumContainer.html#with_port1/2","title":"Testcontainers.Container.SeleniumContainer.with_port1/2","type":"function"},{"doc":"","ref":"Testcontainers.Container.SeleniumContainer.html#with_port2/2","title":"Testcontainers.Container.SeleniumContainer.with_port2/2","type":"function"},{"doc":"","ref":"Testcontainers.Container.SeleniumContainer.html#with_wait_timeout/2","title":"Testcontainers.Container.SeleniumContainer.with_wait_timeout/2","type":"function"},{"doc":"All types of predefined containers must implement this protocol.","ref":"Testcontainers.ContainerBuilder.html","title":"Testcontainers.ContainerBuilder","type":"protocol"},{"doc":"Do stuff after container has started.","ref":"Testcontainers.ContainerBuilder.html#after_start/3","title":"Testcontainers.ContainerBuilder.after_start/3","type":"function"},{"doc":"","ref":"Testcontainers.ContainerBuilder.html#build/1","title":"Testcontainers.ContainerBuilder.build/1","type":"function"},{"doc":"","ref":"Testcontainers.ContainerBuilder.html#t:t/0","title":"Testcontainers.ContainerBuilder.t/0","type":"type"},{"doc":"A behaviour implemented by database containers used by `Testcontainers.Ecto`","ref":"Testcontainers.DatabaseBehaviour.html","title":"Testcontainers.DatabaseBehaviour","type":"behaviour"},{"doc":"","ref":"Testcontainers.DatabaseBehaviour.html#c:new/0","title":"Testcontainers.DatabaseBehaviour.new/0","type":"callback"},{"doc":"","ref":"Testcontainers.DatabaseBehaviour.html#c:with_database/2","title":"Testcontainers.DatabaseBehaviour.with_database/2","type":"callback"},{"doc":"","ref":"Testcontainers.DatabaseBehaviour.html#c:with_image/2","title":"Testcontainers.DatabaseBehaviour.with_image/2","type":"callback"},{"doc":"","ref":"Testcontainers.DatabaseBehaviour.html#c:with_password/2","title":"Testcontainers.DatabaseBehaviour.with_password/2","type":"callback"},{"doc":"","ref":"Testcontainers.DatabaseBehaviour.html#c:with_persistent_volume/2","title":"Testcontainers.DatabaseBehaviour.with_persistent_volume/2","type":"callback"},{"doc":"","ref":"Testcontainers.DatabaseBehaviour.html#c:with_port/2","title":"Testcontainers.DatabaseBehaviour.with_port/2","type":"callback"},{"doc":"","ref":"Testcontainers.DatabaseBehaviour.html#c:with_user/2","title":"Testcontainers.DatabaseBehaviour.with_user/2","type":"callback"},{"doc":"","ref":"Testcontainers.DatabaseBehaviour.html#t:t/0","title":"Testcontainers.DatabaseBehaviour.t/0","type":"type"},{"doc":"Internal docker api. Only for direct use by `Testcontainers`","ref":"Testcontainers.Docker.Api.html","title":"Testcontainers.Docker.Api","type":"module"},{"doc":"","ref":"Testcontainers.Docker.Api.html#create_container/2","title":"Testcontainers.Docker.Api.create_container/2","type":"function"},{"doc":"","ref":"Testcontainers.Docker.Api.html#get_bridge_gateway/1","title":"Testcontainers.Docker.Api.get_bridge_gateway/1","type":"function"},{"doc":"","ref":"Testcontainers.Docker.Api.html#get_container/2","title":"Testcontainers.Docker.Api.get_container/2","type":"function"},{"doc":"","ref":"Testcontainers.Docker.Api.html#inspect_exec/2","title":"Testcontainers.Docker.Api.inspect_exec/2","type":"function"},{"doc":"","ref":"Testcontainers.Docker.Api.html#pull_image/3","title":"Testcontainers.Docker.Api.pull_image/3","type":"function"},{"doc":"","ref":"Testcontainers.Docker.Api.html#put_file/5","title":"Testcontainers.Docker.Api.put_file/5","type":"function"},{"doc":"","ref":"Testcontainers.Docker.Api.html#start_container/2","title":"Testcontainers.Docker.Api.start_container/2","type":"function"},{"doc":"","ref":"Testcontainers.Docker.Api.html#start_exec/3","title":"Testcontainers.Docker.Api.start_exec/3","type":"function"},{"doc":"","ref":"Testcontainers.Docker.Api.html#stdout_logs/2","title":"Testcontainers.Docker.Api.stdout_logs/2","type":"function"},{"doc":"","ref":"Testcontainers.Docker.Api.html#stop_container/2","title":"Testcontainers.Docker.Api.stop_container/2","type":"function"},{"doc":"Facilitates the creation of a Postgres or MySql container for testing with Ecto.\n\nThis module simplifies the process of launching a real Postgres or MySql database instance within a Docker container for testing purposes. It leverages the `Testcontainers` library to instantiate a Postgres or MySql container with the desired configuration, providing an isolated database environment for each test session.","ref":"Testcontainers.Ecto.html","title":"Testcontainers.Ecto","type":"module"},{"doc":"Initiates a new Mysql instance, executes migrations, and prepares a suitable database environment, specifically tailored for testing scenarios.","ref":"Testcontainers.Ecto.html#mysql_container/1","title":"Testcontainers.Ecto.mysql_container/1","type":"function"},{"doc":"- `options`: Configurations for the Mysql container, provided as a keyword list. The only required option is `:app`. Other options include:\n  - `:app` - The current application's atom, necessary for building paths and other application-specific logic. This is a required parameter.\n  - `:repo` (optional) - The Ecto repository module for database interaction. If not provided, it is inferred from the `:app` option using the default naming convention (e.g., `MyApp.Repo`).\n  - `:image` (optional) - Specifies the Docker image for the Mysql container. This must be a legitimate Mysql image, with the image name beginning with \"mysql\". If omitted, the default is \"mysql:8\".\n  - `:user` (optional) - Sets the username for the Mysql instance (defaults to \"test\").\n  - `:password` (optional) - Determines the password for the Mysql user (defaults to \"test\").\n  - `:database` (optional) - Specifies the name of the database to be created within the Mysql instance. If not provided, the default behavior is to create a database with the name derived from the application's atom, appended with \"_test\".\n  - `:migrations_path` (optional) - Indicates the path to the migrations folder (defaults to \"priv/repo/migrations\").\n  - `:persistent_volume_name` (optional, EXPERIMENTAL) - Sets a named volume for the data in the database. This is an experimental option, and changes in database container image or other things that could invalidate the data, would make the container not start properly.\n  - `:check_image` (optional) - Defines a custom regular expression that is used to validate the Docker image.","ref":"Testcontainers.Ecto.html#mysql_container/1-parameters","title":"Parameters - Testcontainers.Ecto.mysql_container/1","type":"function"},{"doc":"It's important to note that the Mysql database initiated by this function will remain operational for the duration of the test process and is not explicitly shut down by the function. The database and its corresponding data are ephemeral, lasting only for the scope of the test session.\n\nAfter the tests conclude, Testcontainers will clean up by removing the database container, ensuring no residual data persists. This approach helps maintain a clean testing environment and prevents any unintended side effects on subsequent tests due to data leftovers.\n\nUsers should not rely on any manual teardown or cleanup for the database, as Testcontainers handles this aspect automatically, providing isolated, repeatable test runs.","ref":"Testcontainers.Ecto.html#mysql_container/1-database-lifecycle-in-testing","title":"Database Lifecycle in Testing - Testcontainers.Ecto.mysql_container/1","type":"function"},{"doc":"# First, you must change the Ecto adapter from Postgres to MyXQL\n\n    defmodule MyApp.Repo do\n      use Ecto.Repo,\n        otp_app: :my_app,\n        adapter: Ecto.Adapters.MyXQL # <- should look like this\n    end\n\n    # Then, in your application.ex file in your Phoenix project:\n\n    import Testcontainers.Ecto\n\n    @impl true\n    def start(_type, _args) do\n      mysql_container(\n        app: :my_app,\n        user: \"postgres\", # consider changing this to something else here and in config/test.exs\n        password: \"postgres\" # consider changing this to something else here and in config/test.exs\n      )\n\n      # .. other setup code\n    end\n\n    # Lastly, in mix.exs, modify the aliases to remove default Ecto setup tasks from the test alias,\n    # as they might interfere with the container-based database setup:\n\n    def aliases do\n      [\n        # ... other aliases\n\n        # Ensure the following line is NOT present, as it would conflict with the container setup:\n        # test: [\"ecto.create --quiet\", \"ecto.migrate --quiet\", \"test\"],\n      ]\n    end\n\n    # in your config/test.exs, if you want to keep appending the MIX_TEST_PARTITION env variable to the database name,\n    # you must set the database option in mysql_container function to the same value\n\n    config :my_app, MyApp.Repo,\n      username: \"postgres\", # <- consider changing this when using mysql\n      password: \"postgres\", # <- consider changing this when using mysql\n      hostname: \"localhost\",\n      database: \"my_app_test#{System.get_env(\"MIX_TEST_PARTITION\")}\", # set this also in mysql_container function database option, or remove the appending\n      pool: Ecto.Adapters.SQL.Sandbox,\n      pool_size: 10\n\n    # for example, to set the database name to the one above, in application.ex:\n\n    @impl true\n    def start(_type, _args) do\n      mysql_container(\n        app: :my_app,\n        user: \"postgres\", # <- consider changing this when using mysql\n        password: \"postgres\", # <- consider changing this when using mysql\n        database: \"my_app_test#{System.get_env(\"MIX_TEST_PARTITION\")}\"\n      )\n\n      # .. other setup code\n    end","ref":"Testcontainers.Ecto.html#mysql_container/1-examples","title":"Examples - Testcontainers.Ecto.mysql_container/1","type":"function"},{"doc":"- `:ok` if the container is initiated successfully.\n- `{:error, reason}` if there is a failure in initiating the container, with `reason` explaining the cause of the failure.","ref":"Testcontainers.Ecto.html#mysql_container/1-returns","title":"Returns - Testcontainers.Ecto.mysql_container/1","type":"function"},{"doc":"- Raises `ArgumentError` if the application is missing, not an atom, or not loaded.\n- Raises `ArgumentError` if the repo is defined and not an atom\n- Raises `ArgumentError` if the specified Docker image is not a valid MySql image.","ref":"Testcontainers.Ecto.html#mysql_container/1-errors","title":"Errors - Testcontainers.Ecto.mysql_container/1","type":"function"},{"doc":"This utility is intended for testing environments requiring a genuine database instance. It is not suitable for production use. It mandates a valid Mysql Docker image to maintain consistent and reliable testing conditions.","ref":"Testcontainers.Ecto.html#mysql_container/1-note","title":"Note - Testcontainers.Ecto.mysql_container/1","type":"function"},{"doc":"Initiates a new Postgres instance, executes migrations, and prepares a suitable database environment, specifically tailored for testing scenarios.","ref":"Testcontainers.Ecto.html#postgres_container/1","title":"Testcontainers.Ecto.postgres_container/1","type":"function"},{"doc":"- `options`: Configurations for the Postgres container, provided as a keyword list. The only required option is `:app`. Other options include:\n  - `:app` - The current application's atom, necessary for building paths and other application-specific logic. This is a required parameter.\n  - `:repo` (optional) - The Ecto repository module for database interaction. If not provided, it is inferred from the `:app` option using the default naming convention (e.g., `MyApp.Repo`).\n  - `:image` (optional) - Specifies the Docker image for the Postgres container. This must be a legitimate Postgres image, with the image name beginning with \"postgres\". If omitted, the default is \"postgres:15\".\n  - `:user` (optional) - Sets the username for the Postgres instance (defaults to \"postgres\").\n  - `:password` (optional) - Determines the password for the Postgres user (defaults to \"postgres\").\n  - `:database` (optional) - Specifies the name of the database to be created within the Postgres instance. If not provided, the default behavior is to create a database with the name derived from the application's atom, appended with \"_test\".\n  - `:migrations_path` (optional) - Indicates the path to the migrations folder (defaults to \"priv/repo/migrations\").\n  - `:persistent_volume_name` (optional, EXPERIMENTAL) - Sets a named volume for the data in the database. This is an experimental option, and changes in database container image or other things that could invalidate the data, would make the container not start properly.\n  - `:check_image` (optional) - Defines a custom regular expression that is used to validate the Docker image.","ref":"Testcontainers.Ecto.html#postgres_container/1-parameters","title":"Parameters - Testcontainers.Ecto.postgres_container/1","type":"function"},{"doc":"It's important to note that the Postgres database initiated by this function will remain operational for the duration of the test process and is not explicitly shut down by the test. The database and its corresponding data are ephemeral, lasting only for the scope of the test session.\n\nAfter the tests conclude, Testcontainers will clean up by removing the database container, ensuring no residual data persists. This approach helps maintain a clean testing environment and prevents any unintended side effects on subsequent tests due to data leftovers.\n\nUsers should not rely on any manual teardown or cleanup for the database, as Testcontainers handles this aspect automatically, providing isolated, repeatable test runs.","ref":"Testcontainers.Ecto.html#postgres_container/1-database-lifecycle-in-testing","title":"Database Lifecycle in Testing - Testcontainers.Ecto.postgres_container/1","type":"function"},{"doc":"# In your application.ex file in your Phoenix project:\n\n    import Testcontainers.Ecto\n\n    @impl true\n    def start(_type, _args) do\n      postgres_container(\n        app: :my_app,\n        user: \"postgres\",\n        password: \"postgres\"\n      )\n\n      # .. other setup code\n    end\n\n    # In mix.exs, modify the aliases to remove default Ecto setup tasks from the test alias,\n    # as they might interfere with the container-based database setup:\n\n    def aliases do\n      [\n        # ... other aliases\n\n        # Ensure the following line is NOT present, as it would conflict with the container setup:\n        # test: [\"ecto.create --quiet\", \"ecto.migrate --quiet\", \"test\"],\n      ]\n    end\n\n    # in your config/test.exs, if you want to keep appending the MIX_TEST_PARTITION env variable to the database name,\n    # you must set the database option in postgres_container function to the same value\n\n    config :my_app, MyApp.Repo,\n      username: \"postgres\",\n      password: \"postgres\",\n      hostname: \"localhost\",\n      database: \"my_app_test#{System.get_env(\"MIX_TEST_PARTITION\")}\", # set this also in postgres_container function database option, or remove the appending\n      pool: Ecto.Adapters.SQL.Sandbox,\n      pool_size: 10\n\n    # for example, to set the database name to the one above, in application.ex:\n\n    @impl true\n    def start(_type, _args) do\n      postgres_container(\n        app: :my_app,\n        user: \"postgres\",\n        password: \"postgres\",\n        database: \"my_app_test#{System.get_env(\"MIX_TEST_PARTITION\")}\"\n      )\n\n      # .. other setup code\n    end","ref":"Testcontainers.Ecto.html#postgres_container/1-examples","title":"Examples - Testcontainers.Ecto.postgres_container/1","type":"function"},{"doc":"- `:ok` if the container is initiated successfully.\n- `{:error, reason}` if there is a failure in initiating the container, with `reason` explaining the cause of the failure.","ref":"Testcontainers.Ecto.html#postgres_container/1-returns","title":"Returns - Testcontainers.Ecto.postgres_container/1","type":"function"},{"doc":"- Raises `ArgumentError` if the application is missing, not an atom, or not loaded.\n- Raises `ArgumentError` if the repo is defined and not an atom\n- Raises `ArgumentError` if the specified Docker image is not a valid Postgres image.","ref":"Testcontainers.Ecto.html#postgres_container/1-errors","title":"Errors - Testcontainers.Ecto.postgres_container/1","type":"function"},{"doc":"This utility is intended for testing environments requiring a genuine database instance. It is not suitable for production use. It mandates a valid Postgres Docker image to maintain consistent and reliable testing conditions.","ref":"Testcontainers.Ecto.html#postgres_container/1-note","title":"Note - Testcontainers.Ecto.postgres_container/1","type":"function"},{"doc":"Provides functionality for creating and managing EMQX container configurations.","ref":"Testcontainers.EmqxContainer.html","title":"Testcontainers.EmqxContainer","type":"module"},{"doc":"Retrieves the default Docker image for the Emqx container.","ref":"Testcontainers.EmqxContainer.html#default_image/0","title":"Testcontainers.EmqxContainer.default_image/0","type":"function"},{"doc":"Returns the address on the _host machine_ where the Emqx container is listening.","ref":"Testcontainers.EmqxContainer.html#host/0","title":"Testcontainers.EmqxContainer.host/0","type":"function"},{"doc":"Returns the port on the _host machine_ where the Emqx container is listening.","ref":"Testcontainers.EmqxContainer.html#mqtt_port/1","title":"Testcontainers.EmqxContainer.mqtt_port/1","type":"function"},{"doc":"Creates a new `EmqxContainer` struct with default configurations.","ref":"Testcontainers.EmqxContainer.html#new/0","title":"Testcontainers.EmqxContainer.new/0","type":"function"},{"doc":"Set the regular expression to check the image validity.","ref":"Testcontainers.EmqxContainer.html#with_check_image/2","title":"Testcontainers.EmqxContainer.with_check_image/2","type":"function"},{"doc":"Overrides the default image used for the Emqx container.","ref":"Testcontainers.EmqxContainer.html#with_image/2","title":"Testcontainers.EmqxContainer.with_image/2","type":"function"},{"doc":"iex> config = EmqxContainer.new()\n    iex> new_config = EmqxContainer.with_image(config, \"emqx:xyz\")\n    iex> new_config.image\n    \"emqx:xyz\"","ref":"Testcontainers.EmqxContainer.html#with_image/2-examples","title":"Examples - Testcontainers.EmqxContainer.with_image/2","type":"function"},{"doc":"","ref":"Testcontainers.EmqxContainer.html#with_ports/6","title":"Testcontainers.EmqxContainer.with_ports/6","type":"function"},{"doc":"Convenient macros to run containers within ExUnit tests.","ref":"Testcontainers.ExUnit.html","title":"Testcontainers.ExUnit","type":"module"},{"doc":"Creates and manages the lifecycle of a container within ExUnit tests.\n\nWhen the `:shared` option is set to `true`, the container is created once for all tests in the module. It initializes the container before any test is run and keeps it running across multiple tests. This is useful for scenarios where the cost of setting up and tearing down the container is high, or the tests are read-only and won't change the container's state.\n\nWhen the `:shared` option is omitted or set to `false`, a new container is created for each individual test, ensuring a clean state for each test case. The container is removed after each test finishes.","ref":"Testcontainers.ExUnit.html#container/3","title":"Testcontainers.ExUnit.container/3","type":"macro"},{"doc":"* `name`: The key that should be used to reference the container in test cases.\n  * `config`: Configuration necessary for initializing the container.\n  * `options`: Optional keyword list. Supports the following options:\n    * `:shared` - If set to `true`, the container is shared across all tests in the module. If `false` or omitted, a new container is used for each test.","ref":"Testcontainers.ExUnit.html#container/3-parameters","title":"Parameters - Testcontainers.ExUnit.container/3","type":"macro"},{"doc":"To create a new container for each test:\n\n    defmodule MyTest do\n      use ExUnit.Case\n\n      alias Testcontainers.Container\n\n      container :my_container, %Container{image: \"my_image\"}\n      # ...\n    end\n\nTo share a container across all tests in the module:\n\n    defmodule MySharedTest do\n      use ExUnit.Case\n\n      alias Testcontainers.Container\n\n      container :my_shared_container, %Container{image: \"my_shared_image\"}, shared: true\n      # ...\n    end","ref":"Testcontainers.ExUnit.html#container/3-examples","title":"Examples - Testcontainers.ExUnit.container/3","type":"macro"},{"doc":"* The macro sets up the necessary ExUnit callbacks to manage the container's lifecycle.\n  * It ensures the `Connection` and `Reaper` are started before initializing a container.\n  * In the case of shared containers, be mindful that tests can affect the container's state, potentially leading to interdependencies between tests.","ref":"Testcontainers.ExUnit.html#container/3-notes","title":"Notes - Testcontainers.ExUnit.container/3","type":"macro"},{"doc":"Provides functionality for creating and managing Kafka container configurations.","ref":"Testcontainers.KafkaContainer.html","title":"Testcontainers.KafkaContainer","type":"module"},{"doc":"Creates a new `KafkaContainer` struct with default configurations.","ref":"Testcontainers.KafkaContainer.html#new/0","title":"Testcontainers.KafkaContainer.new/0","type":"function"},{"doc":"Overrides the default broker id used for the Kafka container.","ref":"Testcontainers.KafkaContainer.html#with_broker_id/2","title":"Testcontainers.KafkaContainer.with_broker_id/2","type":"function"},{"doc":"Overrides the default kafka port used for the Kafka container.","ref":"Testcontainers.KafkaContainer.html#with_broker_port/2","title":"Testcontainers.KafkaContainer.with_broker_port/2","type":"function"},{"doc":"Overrides the default zookeeper host used for the Kafka container.\nAvailable only when consensus_strategy is kraft","ref":"Testcontainers.KafkaContainer.html#with_cluster_id/2","title":"Testcontainers.KafkaContainer.with_cluster_id/2","type":"function"},{"doc":"Overrides the default consensus strategy used for the Kafka container.","ref":"Testcontainers.KafkaContainer.html#with_consensus_strategy/2","title":"Testcontainers.KafkaContainer.with_consensus_strategy/2","type":"function"},{"doc":"Overrides the default image used for the Kafka container.\nRight now we support only confluentinc images.","ref":"Testcontainers.KafkaContainer.html#with_image/2","title":"Testcontainers.KafkaContainer.with_image/2","type":"function"},{"doc":"Overrides the default kafka port used for the Kafka container.","ref":"Testcontainers.KafkaContainer.html#with_kafka_port/2","title":"Testcontainers.KafkaContainer.with_kafka_port/2","type":"function"},{"doc":"Overrides the default topic","ref":"Testcontainers.KafkaContainer.html#with_topic_partitions/2","title":"Testcontainers.KafkaContainer.with_topic_partitions/2","type":"function"},{"doc":"Overrides the default wait timeout used for the Kafka container.","ref":"Testcontainers.KafkaContainer.html#with_wait_timeout/2","title":"Testcontainers.KafkaContainer.with_wait_timeout/2","type":"function"},{"doc":"Overrides the default zookeeper host used for the Kafka container.\nAvailable only when consensus_strategy is external","ref":"Testcontainers.KafkaContainer.html#with_zookeeper_host/2","title":"Testcontainers.KafkaContainer.with_zookeeper_host/2","type":"function"},{"doc":"Overrides the default zookeeper port used for the Kafka container.","ref":"Testcontainers.KafkaContainer.html#with_zookeeper_port/2","title":"Testcontainers.KafkaContainer.with_zookeeper_port/2","type":"function"},{"doc":"Considers the container as ready as soon as a specific log message is detected in the container's log stream.","ref":"Testcontainers.LogWaitStrategy.html","title":"Testcontainers.LogWaitStrategy","type":"module"},{"doc":"Creates a new LogWaitStrategy.\nThis strategy waits until a specific log message, matching the provided regex, appears in the container's log.","ref":"Testcontainers.LogWaitStrategy.html#new/3","title":"Testcontainers.LogWaitStrategy.new/3","type":"function"},{"doc":"Defines an abstraction on top of Elixir.Logger","ref":"Testcontainers.Logger.html","title":"Testcontainers.Logger","type":"module"},{"doc":"","ref":"Testcontainers.Logger.html#log/1","title":"Testcontainers.Logger.log/1","type":"function"},{"doc":"Provides functionality for creating and managing Minio container configurations.","ref":"Testcontainers.MinioContainer.html","title":"Testcontainers.MinioContainer","type":"module"},{"doc":"Generates the connection options for accessing the Minio service running within the container.\nCompatible with what ex_aws expects in `ExAws.request(options)`","ref":"Testcontainers.MinioContainer.html#connection_opts/1","title":"Testcontainers.MinioContainer.connection_opts/1","type":"function"},{"doc":"Generates the connection URL for accessing the Minio service running within the container.","ref":"Testcontainers.MinioContainer.html#connection_url/1","title":"Testcontainers.MinioContainer.connection_url/1","type":"function"},{"doc":"","ref":"Testcontainers.MinioContainer.html#default_s3_port/0","title":"Testcontainers.MinioContainer.default_s3_port/0","type":"function"},{"doc":"","ref":"Testcontainers.MinioContainer.html#default_ui_port/0","title":"Testcontainers.MinioContainer.default_ui_port/0","type":"function"},{"doc":"","ref":"Testcontainers.MinioContainer.html#get_password/0","title":"Testcontainers.MinioContainer.get_password/0","type":"function"},{"doc":"","ref":"Testcontainers.MinioContainer.html#get_username/0","title":"Testcontainers.MinioContainer.get_username/0","type":"function"},{"doc":"","ref":"Testcontainers.MinioContainer.html#new/0","title":"Testcontainers.MinioContainer.new/0","type":"function"},{"doc":"Retrieves the port mapped by the Docker host for the Minio container.","ref":"Testcontainers.MinioContainer.html#port/1","title":"Testcontainers.MinioContainer.port/1","type":"function"},{"doc":"Provides functionality for creating and managing MySQL container configurations.","ref":"Testcontainers.MySqlContainer.html","title":"Testcontainers.MySqlContainer","type":"module"},{"doc":"Returns the connection parameters to connect to the database from the _host machine_.","ref":"Testcontainers.MySqlContainer.html#connection_parameters/1","title":"Testcontainers.MySqlContainer.connection_parameters/1","type":"function"},{"doc":"Retrieves the default Docker image for the MySQL container.","ref":"Testcontainers.MySqlContainer.html#default_image/0","title":"Testcontainers.MySqlContainer.default_image/0","type":"function"},{"doc":"Retrieves the default Docker image including tag for the MySQL container.","ref":"Testcontainers.MySqlContainer.html#default_image_with_tag/0","title":"Testcontainers.MySqlContainer.default_image_with_tag/0","type":"function"},{"doc":"Retrieves the default exposed port for the MySQL container.","ref":"Testcontainers.MySqlContainer.html#default_port/0","title":"Testcontainers.MySqlContainer.default_port/0","type":"function"},{"doc":"Creates a new `MySqlContainer` struct with default configurations.","ref":"Testcontainers.MySqlContainer.html#new/0","title":"Testcontainers.MySqlContainer.new/0","type":"function"},{"doc":"Returns the port on the _host machine_ where the MySql container is listening.","ref":"Testcontainers.MySqlContainer.html#port/1","title":"Testcontainers.MySqlContainer.port/1","type":"function"},{"doc":"Set the regular expression to check the image validity.","ref":"Testcontainers.MySqlContainer.html#with_check_image/2","title":"Testcontainers.MySqlContainer.with_check_image/2","type":"function"},{"doc":"Overrides the default database used for the MySQL container.","ref":"Testcontainers.MySqlContainer.html#with_database/2","title":"Testcontainers.MySqlContainer.with_database/2","type":"function"},{"doc":"iex> config = MySqlContainer.new()\n    iex> new_config = MySqlContainer.with_database(config, \"another-database\")\n    iex> new_config.database\n    \"another-database\"","ref":"Testcontainers.MySqlContainer.html#with_database/2-examples","title":"Examples - Testcontainers.MySqlContainer.with_database/2","type":"function"},{"doc":"Overrides the default image used for the MySQL container.","ref":"Testcontainers.MySqlContainer.html#with_image/2","title":"Testcontainers.MySqlContainer.with_image/2","type":"function"},{"doc":"iex> config = MySqlContainer.new()\n    iex> new_config = MySqlContainer.with_image(config, \"mysql:4\")\n    iex> new_config.image\n    \"mysql:4\"","ref":"Testcontainers.MySqlContainer.html#with_image/2-examples","title":"Examples - Testcontainers.MySqlContainer.with_image/2","type":"function"},{"doc":"Overrides the default password used for the MySQL container.","ref":"Testcontainers.MySqlContainer.html#with_password/2","title":"Testcontainers.MySqlContainer.with_password/2","type":"function"},{"doc":"iex> config = MySqlContainer.new()\n    iex> new_config = MySqlContainer.with_password(config, \"another-password\")\n    iex> new_config.password\n    \"another-password\"","ref":"Testcontainers.MySqlContainer.html#with_password/2-examples","title":"Examples - Testcontainers.MySqlContainer.with_password/2","type":"function"},{"doc":"","ref":"Testcontainers.MySqlContainer.html#with_persistent_volume/2","title":"Testcontainers.MySqlContainer.with_persistent_volume/2","type":"function"},{"doc":"Overrides the default port used for the MySQL container.\n\nNote: this will not change what port the docker container is listening to internally.","ref":"Testcontainers.MySqlContainer.html#with_port/2","title":"Testcontainers.MySqlContainer.with_port/2","type":"function"},{"doc":"iex> config = MySqlContainer.new()\n    iex> new_config = MySqlContainer.with_port(config, 3307)\n    iex> new_config.port\n    3307","ref":"Testcontainers.MySqlContainer.html#with_port/2-examples","title":"Examples - Testcontainers.MySqlContainer.with_port/2","type":"function"},{"doc":"Overrides the default user used for the MySQL container.","ref":"Testcontainers.MySqlContainer.html#with_user/2","title":"Testcontainers.MySqlContainer.with_user/2","type":"function"},{"doc":"iex> config = MySqlContainer.new()\n    iex> new_config = MySqlContainer.with_user(config, \"another-user\")\n    iex> new_config.user\n    \"another-user\"","ref":"Testcontainers.MySqlContainer.html#with_user/2-examples","title":"Examples - Testcontainers.MySqlContainer.with_user/2","type":"function"},{"doc":"Overrides the default wait timeout used for the MySQL container.\n\nNote: this timeout will be used for each individual wait strategy.","ref":"Testcontainers.MySqlContainer.html#with_wait_timeout/2","title":"Testcontainers.MySqlContainer.with_wait_timeout/2","type":"function"},{"doc":"iex> config = MySqlContainer.new()\n    iex> new_config = MySqlContainer.with_wait_timeout(config, 8000)\n    iex> new_config.wait_timeout\n    8000","ref":"Testcontainers.MySqlContainer.html#with_wait_timeout/2-examples","title":"Examples - Testcontainers.MySqlContainer.with_wait_timeout/2","type":"function"},{"doc":"Considers the container as ready when it successfully accepts connections on the specified port.","ref":"Testcontainers.PortWaitStrategy.html","title":"Testcontainers.PortWaitStrategy","type":"module"},{"doc":"Creates a new PortWaitStrategy to wait until a specified port is open and accepting connections.","ref":"Testcontainers.PortWaitStrategy.html#new/4","title":"Testcontainers.PortWaitStrategy.new/4","type":"function"},{"doc":"Provides functionality for creating and managing Postgres container configurations.","ref":"Testcontainers.PostgresContainer.html","title":"Testcontainers.PostgresContainer","type":"module"},{"doc":"Returns the connection parameters to connect to the database from the _host machine_.","ref":"Testcontainers.PostgresContainer.html#connection_parameters/1","title":"Testcontainers.PostgresContainer.connection_parameters/1","type":"function"},{"doc":"Retrieves the default Docker image for the Postgres container.","ref":"Testcontainers.PostgresContainer.html#default_image/0","title":"Testcontainers.PostgresContainer.default_image/0","type":"function"},{"doc":"Retrieves the default Docker image including tag for the Postgres container.","ref":"Testcontainers.PostgresContainer.html#default_image_with_tag/0","title":"Testcontainers.PostgresContainer.default_image_with_tag/0","type":"function"},{"doc":"Retrieves the default exposed port for the Postgres container.","ref":"Testcontainers.PostgresContainer.html#default_port/0","title":"Testcontainers.PostgresContainer.default_port/0","type":"function"},{"doc":"Creates a new `PostgresContainer` struct with default configurations.","ref":"Testcontainers.PostgresContainer.html#new/0","title":"Testcontainers.PostgresContainer.new/0","type":"function"},{"doc":"Returns the port on the _host machine_ where the Postgres container is listening.","ref":"Testcontainers.PostgresContainer.html#port/1","title":"Testcontainers.PostgresContainer.port/1","type":"function"},{"doc":"Set the regular expression to check the image validity.","ref":"Testcontainers.PostgresContainer.html#with_check_image/2","title":"Testcontainers.PostgresContainer.with_check_image/2","type":"function"},{"doc":"Overrides the default database used for the Postgres container.","ref":"Testcontainers.PostgresContainer.html#with_database/2","title":"Testcontainers.PostgresContainer.with_database/2","type":"function"},{"doc":"iex> config = PostgresContainer.new()\n    iex> new_config = PostgresContainer.with_database(config, \"another-database\")\n    iex> new_config.database\n    \"another-database\"","ref":"Testcontainers.PostgresContainer.html#with_database/2-examples","title":"Examples - Testcontainers.PostgresContainer.with_database/2","type":"function"},{"doc":"Overrides the default image used for the Postgres container.","ref":"Testcontainers.PostgresContainer.html#with_image/2","title":"Testcontainers.PostgresContainer.with_image/2","type":"function"},{"doc":"iex> config = PostgresContainer.new()\n    iex> new_config = PostgresContainer.with_image(config, \"postgres:12\")\n    iex> new_config.image\n    \"postgres:12\"","ref":"Testcontainers.PostgresContainer.html#with_image/2-examples","title":"Examples - Testcontainers.PostgresContainer.with_image/2","type":"function"},{"doc":"Overrides the default password used for the Postgres container.","ref":"Testcontainers.PostgresContainer.html#with_password/2","title":"Testcontainers.PostgresContainer.with_password/2","type":"function"},{"doc":"iex> config = PostgresContainer.new()\n    iex> new_config = PostgresContainer.with_password(config, \"another-password\")\n    iex> new_config.password\n    \"another-password\"","ref":"Testcontainers.PostgresContainer.html#with_password/2-examples","title":"Examples - Testcontainers.PostgresContainer.with_password/2","type":"function"},{"doc":"","ref":"Testcontainers.PostgresContainer.html#with_persistent_volume/2","title":"Testcontainers.PostgresContainer.with_persistent_volume/2","type":"function"},{"doc":"Overrides the default port used for the Postgres container.\n\nNote: this will not change what port the docker container is listening to internally.","ref":"Testcontainers.PostgresContainer.html#with_port/2","title":"Testcontainers.PostgresContainer.with_port/2","type":"function"},{"doc":"iex> config = PostgresContainer.new()\n    iex> new_config = PostgresContainer.with_port(config, 2345)\n    iex> new_config.port\n    2345","ref":"Testcontainers.PostgresContainer.html#with_port/2-examples","title":"Examples - Testcontainers.PostgresContainer.with_port/2","type":"function"},{"doc":"Overrides the default user used for the Postgres container.","ref":"Testcontainers.PostgresContainer.html#with_user/2","title":"Testcontainers.PostgresContainer.with_user/2","type":"function"},{"doc":"iex> config = PostgresContainer.new()\n    iex> new_config = PostgresContainer.with_user(config, \"another-user\")\n    iex> new_config.user\n    \"another-user\"","ref":"Testcontainers.PostgresContainer.html#with_user/2-examples","title":"Examples - Testcontainers.PostgresContainer.with_user/2","type":"function"},{"doc":"Overrides the default wait timeout used for the Postgres container.\n\nNote: this timeout will be used for each individual wait strategy.","ref":"Testcontainers.PostgresContainer.html#with_wait_timeout/2","title":"Testcontainers.PostgresContainer.with_wait_timeout/2","type":"function"},{"doc":"iex> config = PostgresContainer.new()\n    iex> new_config = PostgresContainer.with_wait_timeout(config, 8000)\n    iex> new_config.wait_timeout\n    8000","ref":"Testcontainers.PostgresContainer.html#with_wait_timeout/2-examples","title":"Examples - Testcontainers.PostgresContainer.with_wait_timeout/2","type":"function"},{"doc":"Provides functionality for creating and managing RabbitMQ container configurations.\n\nNOTE: The default starting command is `chmod 400 /var/lib/rabbitmq/.erlang.cookie; rabbitmq-server`.\n`chmod 400 /var/lib/rabbitmq/.erlang.cookie` is necessary for the waiting strategy, which calls the command `rabbitmq-diagnostics check_running`; otherwise CLI tools cannot communicate with the RabbitMQ node.","ref":"Testcontainers.RabbitMQContainer.html","title":"Testcontainers.RabbitMQContainer","type":"module"},{"doc":"Returns the connection parameters to connect to RabbitMQ from the _host machine_.","ref":"Testcontainers.RabbitMQContainer.html#connection_parameters/1","title":"Testcontainers.RabbitMQContainer.connection_parameters/1","type":"function"},{"doc":"- `container`: The active RabbitMQ container instance in the form of a %Container{} struct.","ref":"Testcontainers.RabbitMQContainer.html#connection_parameters/1-parameters","title":"Parameters - Testcontainers.RabbitMQContainer.connection_parameters/1","type":"function"},{"doc":"iex> RabbitMQContainer.connection_parameters(container)\n    [\n      host: \"localhost\",\n      port: 32768,\n      username: \"guest\",\n      password: \"guest\",\n      vhost: \"/\"\n    ]","ref":"Testcontainers.RabbitMQContainer.html#connection_parameters/1-examples","title":"Examples - Testcontainers.RabbitMQContainer.connection_parameters/1","type":"function"},{"doc":"Generates the connection URL for accessing the RabbitMQ service running within the container.\n\nThis URI is based on the AMQP 0-9-1, and has the following scheme:\namqp://username:password@host:port/vhost","ref":"Testcontainers.RabbitMQContainer.html#connection_url/1","title":"Testcontainers.RabbitMQContainer.connection_url/1","type":"function"},{"doc":"- `container`: The active RabbitMQ container instance in the form of a %Container{} struct.","ref":"Testcontainers.RabbitMQContainer.html#connection_url/1-parameters","title":"Parameters - Testcontainers.RabbitMQContainer.connection_url/1","type":"function"},{"doc":"iex> RabbitMQContainer.connection_url(container)\n    \"amqp://guest:guest@localhost:32768\"\n    iex> RabbitMQContainer.connection_url(container_with_vhost)\n    \"amqp://guest:guest@localhost:32768/vhost\"","ref":"Testcontainers.RabbitMQContainer.html#connection_url/1-examples","title":"Examples - Testcontainers.RabbitMQContainer.connection_url/1","type":"function"},{"doc":"Retrieves the default Docker image for the RabbitMQ container","ref":"Testcontainers.RabbitMQContainer.html#default_image/0","title":"Testcontainers.RabbitMQContainer.default_image/0","type":"function"},{"doc":"Retrieves the default Docker image including tag for the RabbitMQ container","ref":"Testcontainers.RabbitMQContainer.html#default_image_with_tag/0","title":"Testcontainers.RabbitMQContainer.default_image_with_tag/0","type":"function"},{"doc":"Retrieves the default exposed port for the RabbitMQ container","ref":"Testcontainers.RabbitMQContainer.html#default_port/0","title":"Testcontainers.RabbitMQContainer.default_port/0","type":"function"},{"doc":"Creates a new `RabbitMQContainer` struct with default configurations.","ref":"Testcontainers.RabbitMQContainer.html#new/0","title":"Testcontainers.RabbitMQContainer.new/0","type":"function"},{"doc":"Returns the port on the _host machine_ where the RabbitMQ container is listening.","ref":"Testcontainers.RabbitMQContainer.html#port/1","title":"Testcontainers.RabbitMQContainer.port/1","type":"function"},{"doc":"Set the regular expression to check the image validity.","ref":"Testcontainers.RabbitMQContainer.html#with_check_image/2","title":"Testcontainers.RabbitMQContainer.with_check_image/2","type":"function"},{"doc":"Overrides the default command used for the RabbitMQ container.","ref":"Testcontainers.RabbitMQContainer.html#with_cmd/2","title":"Testcontainers.RabbitMQContainer.with_cmd/2","type":"function"},{"doc":"iex> config = RabbitMQContainer.new() |> RabbitMQContainer.with_cmd([\"sh\", \"-c\", \"rabbitmq-server\"])\n  iex> config.cmd\n  [\"sh\", \"-c\", \"rabbitmq-server\"]","ref":"Testcontainers.RabbitMQContainer.html#with_cmd/2-examples","title":"Examples - Testcontainers.RabbitMQContainer.with_cmd/2","type":"function"},{"doc":"Overrides the default image use for the RabbitMQ container.","ref":"Testcontainers.RabbitMQContainer.html#with_image/2","title":"Testcontainers.RabbitMQContainer.with_image/2","type":"function"},{"doc":"iex> config = RabbitMQContainer.new() |> RabbitMQContainer.with_image(\"rabbitmq:xyz\")\n  iex> config.image\n  \"rabbitmq:xyz\"","ref":"Testcontainers.RabbitMQContainer.html#with_image/2-examples","title":"Examples - Testcontainers.RabbitMQContainer.with_image/2","type":"function"},{"doc":"Overrides the default password used for the RabbitMQ container.","ref":"Testcontainers.RabbitMQContainer.html#with_password/2","title":"Testcontainers.RabbitMQContainer.with_password/2","type":"function"},{"doc":"iex> config = RabbitMQContainer.new() |> RabbitMQContainer.with_password(\"rabbitmq\")\n  iex> config.password\n  \"rabbitmq\"","ref":"Testcontainers.RabbitMQContainer.html#with_password/2-examples","title":"Examples - Testcontainers.RabbitMQContainer.with_password/2","type":"function"},{"doc":"Overrides the default port used for the RabbitMQ container.","ref":"Testcontainers.RabbitMQContainer.html#with_port/2","title":"Testcontainers.RabbitMQContainer.with_port/2","type":"function"},{"doc":"iex> config = RabbitMQContainer.new() |> RabbitMQContainer.with_port(1111)\n  iex> config.port\n  1111","ref":"Testcontainers.RabbitMQContainer.html#with_port/2-examples","title":"Examples - Testcontainers.RabbitMQContainer.with_port/2","type":"function"},{"doc":"Overrides the default user used for the RabbitMQ container.","ref":"Testcontainers.RabbitMQContainer.html#with_username/2","title":"Testcontainers.RabbitMQContainer.with_username/2","type":"function"},{"doc":"iex> config = RabbitMQContainer.new() |> RabbitMQContainer.with_username(\"rabbitmq\")\n  iex> config.username\n  \"rabbitmq\"","ref":"Testcontainers.RabbitMQContainer.html#with_username/2-examples","title":"Examples - Testcontainers.RabbitMQContainer.with_username/2","type":"function"},{"doc":"Overrides the default virtual host used for the RabbitMQ container.","ref":"Testcontainers.RabbitMQContainer.html#with_virtual_host/2","title":"Testcontainers.RabbitMQContainer.with_virtual_host/2","type":"function"},{"doc":"iex> config = RabbitMQContainer.new() |> RabbitMQContainer.with_virtual_host(\"/\")\n  iex> config.password\n  \"/\"","ref":"Testcontainers.RabbitMQContainer.html#with_virtual_host/2-examples","title":"Examples - Testcontainers.RabbitMQContainer.with_virtual_host/2","type":"function"},{"doc":"Overrides the default wait timeout used for the RabbitMQ container.\n\nNote: this timeout will be used for each individual wait strategy.","ref":"Testcontainers.RabbitMQContainer.html#with_wait_timeout/2","title":"Testcontainers.RabbitMQContainer.with_wait_timeout/2","type":"function"},{"doc":"iex> config = RabbitMQContainer.new() |> RabbitMQContainer.with_wait_timeout(60000)\n  iex> config.wait_timeout\n  60000","ref":"Testcontainers.RabbitMQContainer.html#with_wait_timeout/2-examples","title":"Examples - Testcontainers.RabbitMQContainer.with_wait_timeout/2","type":"function"},{"doc":"Provides functionality for creating and managing Redis container configurations.","ref":"Testcontainers.RedisContainer.html","title":"Testcontainers.RedisContainer","type":"module"},{"doc":"Generates the connection URL for accessing the Redis service running within the container.\n\nThis URL is based on the standard localhost IP and the mapped port for the container.","ref":"Testcontainers.RedisContainer.html#connection_url/1","title":"Testcontainers.RedisContainer.connection_url/1","type":"function"},{"doc":"- `container`: The active Redis container instance in the form of a %Container{} struct.","ref":"Testcontainers.RedisContainer.html#connection_url/1-parameters","title":"Parameters - Testcontainers.RedisContainer.connection_url/1","type":"function"},{"doc":"iex> RedisContainer.connection_url(container)\n    \"http://localhost:32768\" # This value will be different depending on the mapped port.","ref":"Testcontainers.RedisContainer.html#connection_url/1-examples","title":"Examples - Testcontainers.RedisContainer.connection_url/1","type":"function"},{"doc":"Retrieves the default Docker image for the Redis container.","ref":"Testcontainers.RedisContainer.html#default_image/0","title":"Testcontainers.RedisContainer.default_image/0","type":"function"},{"doc":"Creates a new `RedisContainer` struct with default configurations.","ref":"Testcontainers.RedisContainer.html#new/0","title":"Testcontainers.RedisContainer.new/0","type":"function"},{"doc":"Returns the port on the _host machine_ where the Redis container is listening.","ref":"Testcontainers.RedisContainer.html#port/1","title":"Testcontainers.RedisContainer.port/1","type":"function"},{"doc":"Set the regular expression to check the image validity.","ref":"Testcontainers.RedisContainer.html#with_check_image/2","title":"Testcontainers.RedisContainer.with_check_image/2","type":"function"},{"doc":"Overrides the default image used for the Redis container.","ref":"Testcontainers.RedisContainer.html#with_image/2","title":"Testcontainers.RedisContainer.with_image/2","type":"function"},{"doc":"iex> config = RedisContainer.new()\n    iex> new_config = RedisContainer.with_image(config, \"redis:xyz\")\n    iex> new_config.image\n    \"redis:xyz\"","ref":"Testcontainers.RedisContainer.html#with_image/2-examples","title":"Examples - Testcontainers.RedisContainer.with_image/2","type":"function"},{"doc":"Overrides the default port used for the Redis container.\n\nNote: this will not change what port the docker container is listening to internally.","ref":"Testcontainers.RedisContainer.html#with_port/2","title":"Testcontainers.RedisContainer.with_port/2","type":"function"},{"doc":"iex> config = RedisContainer.new()\n    iex> new_config = RedisContainer.with_port(config, 1111)\n    iex> new_config.port\n    1111","ref":"Testcontainers.RedisContainer.html#with_port/2-examples","title":"Examples - Testcontainers.RedisContainer.with_port/2","type":"function"},{"doc":"Overrides the default wait timeout used for the Redis container.\n\nNote: this timeout will be used for each individual wait strategy.","ref":"Testcontainers.RedisContainer.html#with_wait_timeout/2","title":"Testcontainers.RedisContainer.with_wait_timeout/2","type":"function"},{"doc":"iex> config = RedisContainer.new()\n    iex> new_config = RedisContainer.with_wait_timeout(config, 8000)\n    iex> new_config.wait_timeout\n    8000","ref":"Testcontainers.RedisContainer.html#with_wait_timeout/2-examples","title":"Examples - Testcontainers.RedisContainer.with_wait_timeout/2","type":"function"},{"doc":"Work in progress. Not stable for use yet. Not yet documented for this very reason.\nCan use https://github.com/stuart/elixir-webdriver for client in tests","ref":"Testcontainers.SeleniumContainer.html","title":"Testcontainers.SeleniumContainer","type":"module"},{"doc":"","ref":"Testcontainers.SeleniumContainer.html#default_image/0","title":"Testcontainers.SeleniumContainer.default_image/0","type":"function"},{"doc":"","ref":"Testcontainers.SeleniumContainer.html#new/0","title":"Testcontainers.SeleniumContainer.new/0","type":"function"},{"doc":"Set the regular expression to check the image validity.","ref":"Testcontainers.SeleniumContainer.html#with_check_image/2","title":"Testcontainers.SeleniumContainer.with_check_image/2","type":"function"},{"doc":"","ref":"Testcontainers.SeleniumContainer.html#with_image/2","title":"Testcontainers.SeleniumContainer.with_image/2","type":"function"},{"doc":"","ref":"Testcontainers.SeleniumContainer.html#with_port1/2","title":"Testcontainers.SeleniumContainer.with_port1/2","type":"function"},{"doc":"","ref":"Testcontainers.SeleniumContainer.html#with_port2/2","title":"Testcontainers.SeleniumContainer.with_port2/2","type":"function"},{"doc":"","ref":"Testcontainers.SeleniumContainer.html#with_wait_timeout/2","title":"Testcontainers.SeleniumContainer.with_wait_timeout/2","type":"function"},{"doc":"Defines the protocol/interface for the wait strategies in `Testcontainers`","ref":"Testcontainers.WaitStrategy.html","title":"Testcontainers.WaitStrategy","type":"protocol"},{"doc":"","ref":"Testcontainers.WaitStrategy.html#wait_until_container_is_ready/3","title":"Testcontainers.WaitStrategy.wait_until_container_is_ready/3","type":"function"},{"doc":"","ref":"Testcontainers.WaitStrategy.html#t:t/0","title":"Testcontainers.WaitStrategy.t/0","type":"type"}],"producer":{"name":"ex_doc","version":[48,46,51,52,46,49]}}